@@ -9,7 +9,7 @@ class ExecAction:
 
     def __call__(self, connection):
         logger_format_fields['host'] = connection.host
-        with cnx.cd(self.directory) if self.directory else contextlib.nullcontext():
+        with connection.cd(self.directory) if self.directory else contextlib.nullcontext():
             logger.critical(f'Executing: "{self.command}"', extra=logger_format_fields)
             result = connection.run(self.command, hide=True)
             if result.stdout:
