@@ -10,7 +10,7 @@ class UploadAction:
 
     def __call__(self, connection):
         logger_format_fields['host'] = connection.host
-        with cnx.cd(self.directory) if self.directory else contextlib.nullcontext():
+        with connection.cd(self.directory) if self.directory else contextlib.nullcontext():
             logger.critical(f'Uploading "{self.local}"', extra=logger_format_fields)
             result = connection.put(self.local, self.remote)
             logger.debug(f'Uploaded: "{result.remote}"', extra=logger_format_fields)
